==> node-v16.11.1.tar.xz: node-v16.11.1/deps/npm/test/fixtures/libnpmsearch-stream-result.js <==
module.exports = [
  {
    name: 'libnpm',
    scope: 'unscoped',
    version: '3.0.1',
    description: 'Collection of programmatic APIs for the npm CLI',
    keywords: ['npm', 'api', 'package manager', 'lib'],
    date: new Date('2019-07-16T17:50:00.572Z'),
    links: {
      npm: 'https://www.npmjs.com/package/libnpm',
      homepage: 'https://github.com/npm/libnpm#readme',
      repository: 'https://github.com/npm/libnpm',
      bugs: 'https://github.com/npm/libnpm/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@zkat.tech' },
    publisher: { username: 'isaacs', email: 'i@izs.me' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: 'libnpmaccess',
    scope: 'unscoped',
    version: '4.0.1',
    description: 'programmatic library for `npm access` commands',
    date: new Date('2020-11-03T19:19:00.526Z'),
    links: {
      npm: 'https://www.npmjs.com/package/libnpmaccess',
      homepage: 'https://npmjs.com/package/libnpmaccess',
      repository: 'https://github.com/npm/libnpmaccess',
      bugs: 'https://github.com/npm/libnpmaccess/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@sykosomatic.org' },
    publisher: { username: 'nlf', email: 'quitlahok@gmail.com' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: '@evocateur/libnpmaccess',
    scope: 'evocateur',
    version: '3.1.2',
    description: 'programmatic library for `npm access` commands',
    date: new Date('2019-07-16T19:43:33.959Z'),
    links: {
      npm: 'https://www.npmjs.com/package/%40evocateur%2Flibnpmaccess',
      homepage: 'https://npmjs.com/package/@evocateur/libnpmaccess',
      repository: 'https://github.com/evocateur/libnpmaccess',
      bugs: 'https://github.com/evocateur/libnpmaccess/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@zkat.tech' },
    publisher: { username: 'evocateur', email: 'daniel.stockman@gmail.com' },
    maintainers: [{ username: 'evocateur', email: 'daniel.stockman@gmail.com' }],
  },
  {
    name: '@evocateur/libnpmpublish',
    scope: 'evocateur',
    version: '1.2.2',
    description: 'Programmatic API for the bits behind npm publish and unpublish',
    date: new Date('2019-07-16T19:40:40.850Z'),
    links: {
      npm: 'https://www.npmjs.com/package/%40evocateur%2Flibnpmpublish',
      homepage: 'https://npmjs.com/package/@evocateur/libnpmpublish',
      repository: 'https://github.com/evocateur/libnpmpublish',
      bugs: 'https://github.com/evocateur/libnpmpublish/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@zkat.tech' },
    publisher: { username: 'evocateur', email: 'daniel.stockman@gmail.com' },
    maintainers: [{ username: 'evocateur', email: 'daniel.stockman@gmail.com' }],
  },
  {
    name: 'libnpmorg',
    scope: 'unscoped',
    version: '2.0.1',
    description: 'Programmatic api for `npm org` commands',
    keywords: ['libnpm', 'npm', 'package manager', 'api', 'orgs', 'teams'],
    date: new Date('2020-11-03T19:21:57.757Z'),
    links: {
      npm: 'https://www.npmjs.com/package/libnpmorg',
      homepage: 'https://npmjs.com/package/libnpmorg',
      repository: 'https://github.com/npm/libnpmorg',
      bugs: 'https://github.com/npm/libnpmorg/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@sykosomatic.org' },
    publisher: { username: 'nlf', email: 'quitlahok@gmail.com' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: 'libnpmsearch',
    scope: 'unscoped',
    version: '3.1.0',
    description: 'Programmatic API for searching in npm and compatible registries.',
    keywords: ['npm', 'search', 'api', 'libnpm'],
    date: new Date('2020-12-08T23:54:18.374Z'),
    links: {
      npm: 'https://www.npmjs.com/package/libnpmsearch',
      homepage: 'https://npmjs.com/package/libnpmsearch',
      repository: 'https://github.com/npm/libnpmsearch',
      bugs: 'https://github.com/npm/libnpmsearch/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@sykosomatic.org' },
    publisher: { username: 'isaacs', email: 'i@izs.me' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: 'libnpmteam',
    scope: 'unscoped',
    version: '2.0.2',
    description: 'npm Team management APIs',
    date: new Date('2020-11-03T19:24:42.380Z'),
    links: {
      npm: 'https://www.npmjs.com/package/libnpmteam',
      homepage: 'https://npmjs.com/package/libnpmteam',
      repository: 'https://github.com/npm/libnpmteam',
      bugs: 'https://github.com/npm/libnpmteam/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@zkat.tech' },
    publisher: { username: 'nlf', email: 'quitlahok@gmail.com' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: 'libnpmhook',
    scope: 'unscoped',
    version: '6.0.1',
    description: 'programmatic API for managing npm registry hooks',
    keywords: ['npm', 'hooks', 'registry', 'npm api'],
    date: new Date('2020-11-03T19:20:45.818Z'),
    links: {
      npm: 'https://www.npmjs.com/package/libnpmhook',
      homepage: 'https://github.com/npm/libnpmhook#readme',
      repository: 'https://github.com/npm/libnpmhook',
      bugs: 'https://github.com/npm/libnpmhook/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@sykosomatic.org' },
    publisher: { username: 'nlf', email: 'quitlahok@gmail.com' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: 'libnpmpublish',
    scope: 'unscoped',
    version: '4.0.0',
    description: 'Programmatic API for the bits behind npm publish and unpublish',
    date: new Date('2020-11-03T19:13:43.780Z'),
    links: {
      npm: 'https://www.npmjs.com/package/libnpmpublish',
      homepage: 'https://npmjs.com/package/libnpmpublish',
      repository: 'https://github.com/npm/libnpmpublish',
      bugs: 'https://github.com/npm/libnpmpublish/issues',
    },
    author: { name: 'npm Inc.', email: 'support@npmjs.com' },
    publisher: { username: 'nlf', email: 'quitlahok@gmail.com' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: 'libnpmfund',
    scope: 'unscoped',
    version: '1.0.2',
    description: 'Programmatic API for npm fund',
    keywords: [
      'npm', 'npmcli',
      'libnpm', 'cli',
      'git', 'fund',
      'gitfund',
    ],
    date: new Date('2020-12-08T23:22:00.213Z'),
    links: {
      npm: 'https://www.npmjs.com/package/libnpmfund',
      homepage: 'https://github.com/npm/libnpmfund#readme',
      repository: 'https://github.com/npm/libnpmfund',
      bugs: 'https://github.com/npm/libnpmfund/issues',
    },
    author: { name: 'npm Inc.', email: 'support@npmjs.com' },
    publisher: { username: 'isaacs', email: 'i@izs.me' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: '@npmcli/map-workspaces',
    scope: 'npmcli',
    version: '1.0.1',
    description: 'Retrieves a name:pathname Map for a given workspaces config',
    keywords: [
      'npm',
      'npmcli',
      'libnpm',
      'cli',
      'workspaces',
      'map-workspaces',
    ],
    date: new Date('2020-09-30T15:16:29.017Z'),
    links: {
      npm: 'https://www.npmjs.com/package/%40npmcli%2Fmap-workspaces',
      homepage: 'https://github.com/npm/map-workspaces#readme',
      repository: 'https://github.com/npm/map-workspaces',
      bugs: 'https://github.com/npm/map-workspaces/issues',
    },
    author: { name: 'npm Inc.', email: 'support@npmjs.com' },
    publisher: { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: 'libnpmversion',
    scope: 'unscoped',
    version: '1.0.7',
    description: "library to do the things that 'npm version' does",
    date: new Date('2020-11-04T00:21:41.069Z'),
    links: {
      npm: 'https://www.npmjs.com/package/libnpmversion',
      homepage: 'https://github.com/npm/libnpmversion#readme',
      repository: 'https://github.com/npm/libnpmversion',
      bugs: 'https://github.com/npm/libnpmversion/issues',
    },
    author: {
      name: 'Isaac Z. Schlueter',
      email: 'i@izs.me',
      url: 'https://izs.me',
      username: 'isaacs',
    },
    publisher: { username: 'isaacs', email: 'i@izs.me' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: '@types/libnpmsearch',
    scope: 'types',
    version: '2.0.1',
    description: 'TypeScript definitions for libnpmsearch',
    date: new Date('2019-09-26T22:24:28.713Z'),
    links: { npm: 'https://www.npmjs.com/package/%40types%2Flibnpmsearch' },
    publisher: { username: 'types', email: 'ts-npm-types@microsoft.com' },
    maintainers: [{ username: 'types', email: 'ts-npm-types@microsoft.com' }],
  },
]

==> node-v20.6.1.tar.xz: node-v20.6.1/deps/npm/test/fixtures/libnpmsearch-stream-result.js <==
module.exports = [
  {
    name: 'libnpm',
    scope: 'unscoped',
    version: '3.0.1',
    description: 'Collection of programmatic APIs for the npm CLI',
    keywords: ['npm', 'api', 'package manager', 'lib'],
    date: '2019-07-16T17:50:00.572Z',
    links: {
      npm: 'https://www.npmjs.com/package/libnpm',
      homepage: 'https://github.com/npm/libnpm#readme',
      repository: 'https://github.com/npm/libnpm',
      bugs: 'https://github.com/npm/libnpm/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@zkat.tech' },
    publisher: { username: 'isaacs', email: 'i@izs.me' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: 'libnpmaccess',
    scope: 'unscoped',
    version: '4.0.1',
    description: 'programmatic library for `npm access` commands',
    keywords: 'libnpmaccess',
    date: '2020-11-03T19:19:00.526Z',
    links: {
      npm: 'https://www.npmjs.com/package/libnpmaccess',
      homepage: 'https://npmjs.com/package/libnpmaccess',
      repository: 'https://github.com/npm/libnpmaccess',
      bugs: 'https://github.com/npm/libnpmaccess/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@sykosomatic.org' },
    publisher: { username: 'nlf', email: 'quitlahok@gmail.com' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: '@evocateur/libnpmaccess',
    scope: 'evocateur',
    version: '3.1.2',
    description: 'programmatic library for `npm access` commands',
    date: '2019-07-16T19:43:33.959Z',
    links: {
      npm: 'https://www.npmjs.com/package/%40evocateur%2Flibnpmaccess',
      homepage: 'https://npmjs.com/package/@evocateur/libnpmaccess',
      repository: 'https://github.com/evocateur/libnpmaccess',
      bugs: 'https://github.com/evocateur/libnpmaccess/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@zkat.tech' },
    publisher: { username: 'evocateur', email: 'daniel.stockman@gmail.com' },
    maintainers: [{ username: 'evocateur', email: 'daniel.stockman@gmail.com' }],
  },
  {
    name: '@evocateur/libnpmpublish',
    scope: 'evocateur',
    version: '1.2.2',
    description: 'Programmatic API for the bits behind npm publish and unpublish',
    date: '2019-07-16T19:40:40.850Z',
    links: {
      npm: 'https://www.npmjs.com/package/%40evocateur%2Flibnpmpublish',
      homepage: 'https://npmjs.com/package/@evocateur/libnpmpublish',
      repository: 'https://github.com/evocateur/libnpmpublish',
      bugs: 'https://github.com/evocateur/libnpmpublish/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@zkat.tech' },
    publisher: { username: 'evocateur', email: 'daniel.stockman@gmail.com' },
    maintainers: [{ username: 'evocateur', email: 'daniel.stockman@gmail.com' }],
  },
  {
    name: 'libnpmorg',
    scope: 'unscoped',
    version: '2.0.1',
    description: 'Programmatic api for `npm org` commands',
    keywords: ['libnpm', 'npm', 'package manager', 'api', 'orgs', 'teams'],
    date: '2020-11-03T19:21:57.757Z',
    links: {
      npm: 'https://www.npmjs.com/package/libnpmorg',
      homepage: 'https://npmjs.com/package/libnpmorg',
      repository: 'https://github.com/npm/libnpmorg',
      bugs: 'https://github.com/npm/libnpmorg/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@sykosomatic.org' },
    publisher: { username: 'nlf', email: 'quitlahok@gmail.com' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: 'libnpmsearch',
    scope: 'unscoped',
    version: '3.1.0',
    description: 'Programmatic API for searching in npm and compatible registries.',
    keywords: ['npm', 'search', 'api', 'libnpm'],
    date: '2020-12-08T23:54:18.374Z',
    links: {
      npm: 'https://www.npmjs.com/package/libnpmsearch',
      homepage: 'https://npmjs.com/package/libnpmsearch',
      repository: 'https://github.com/npm/libnpmsearch',
      bugs: 'https://github.com/npm/libnpmsearch/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@sykosomatic.org' },
    publisher: { username: 'isaacs', email: 'i@izs.me' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: 'libnpmteam',
    scope: 'unscoped',
    version: '2.0.2',
    description: 'npm Team management APIs',
    date: '2020-11-03T19:24:42.380Z',
    links: {
      npm: 'https://www.npmjs.com/package/libnpmteam',
      homepage: 'https://npmjs.com/package/libnpmteam',
      repository: 'https://github.com/npm/libnpmteam',
      bugs: 'https://github.com/npm/libnpmteam/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@zkat.tech' },
    publisher: { username: 'nlf', email: 'quitlahok@gmail.com' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: 'libnpmhook',
    scope: 'unscoped',
    version: '6.0.1',
    description: 'programmatic API for managing npm registry hooks',
    keywords: ['npm', 'hooks', 'registry', 'npm api'],
    date: '2020-11-03T19:20:45.818Z',
    links: {
      npm: 'https://www.npmjs.com/package/libnpmhook',
      homepage: 'https://github.com/npm/libnpmhook#readme',
      repository: 'https://github.com/npm/libnpmhook',
      bugs: 'https://github.com/npm/libnpmhook/issues',
    },
    author: { name: 'Kat Marchán', email: 'kzm@sykosomatic.org' },
    publisher: { username: 'nlf', email: 'quitlahok@gmail.com' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: 'libnpmpublish',
    scope: 'unscoped',
    version: '4.0.0',
    description: 'Programmatic API for the bits behind npm publish and unpublish',
    date: '2020-11-03T19:13:43.780Z',
    links: {
      npm: 'https://www.npmjs.com/package/libnpmpublish',
      homepage: 'https://npmjs.com/package/libnpmpublish',
      repository: 'https://github.com/npm/libnpmpublish',
      bugs: 'https://github.com/npm/libnpmpublish/issues',
    },
    author: { name: 'npm Inc.', email: 'support@npmjs.com' },
    publisher: { username: 'nlf', email: 'quitlahok@gmail.com' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: 'libnpmfund',
    scope: 'unscoped',
    version: '1.0.2',
    description: 'Programmatic API for npm fund',
    keywords: [
      'npm', 'npmcli',
      'libnpm', 'cli',
      'git', 'fund',
      'gitfund',
    ],
    date: '2020-12-08T23:22:00.213Z',
    links: {
      npm: 'https://www.npmjs.com/package/libnpmfund',
      homepage: 'https://github.com/npm/libnpmfund#readme',
      repository: 'https://github.com/npm/libnpmfund',
      bugs: 'https://github.com/npm/libnpmfund/issues',
    },
    author: { name: 'npm Inc.', email: 'support@npmjs.com' },
    publisher: { username: 'isaacs', email: 'i@izs.me' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: '@npmcli/map-workspaces',
    scope: 'npmcli',
    version: '1.0.1',
    description: 'Retrieves a name:pathname Map for a given workspaces config',
    keywords: [
      '\x1B[33mnpm\x1B[39m',
      'npmcli',
      'libnpm',
      'cli',
      'workspaces',
      'map-workspaces',
    ],
    date: '2020-09-30T15:16:29.017Z',
    links: {
      npm: 'https://www.npmjs.com/package/%40npmcli%2Fmap-workspaces',
      homepage: 'https://github.com/npm/map-workspaces#readme',
      repository: 'https://github.com/npm/map-workspaces',
      bugs: 'https://github.com/npm/map-workspaces/issues',
    },
    author: { name: 'npm Inc.', email: 'support@npmjs.com' },
    publisher: { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
    maintainers: [
      { username: 'nlf', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: '\x1B[31mlibnpmversion\x1B[39m',
    scope: 'unscoped',
    version: '1.0.7',
    description: "library to do the things that '\x1B[32mnpm version\x1B[39m' does",
    date: '2020-11-04T00:21:41.069Z',
    links: {
      npm: 'https://www.npmjs.com/package/libnpmversion',
      homepage: 'https://github.com/npm/libnpmversion#readme',
      repository: 'https://github.com/npm/libnpmversion',
      bugs: 'https://github.com/npm/libnpmversion/issues',
    },
    author: {
      name: 'Isaac Z. Schlueter',
      email: 'i@izs.me',
      url: 'https://izs.me',
      username: 'isaacs',
    },
    publisher: { username: 'isaacs', email: 'i@izs.me' },
    maintainers: [
      { username: '\x1B[34mnlf\x1B[39m', email: 'quitlahok@gmail.com' },
      { username: 'ruyadorno', email: 'ruyadorno@hotmail.com' },
      { username: 'darcyclarke', email: 'darcy@darcyclarke.me' },
      { username: 'isaacs', email: 'i@izs.me' },
    ],
  },
  {
    name: '@types/libnpmsearch',
    scope: 'types',
    version: '2.0.1',
    description: 'TypeScript definitions for libnpmsearch',
    date: '2019-09-26T22:24:28.713Z',
    links: { npm: 'https://www.npmjs.com/package/%40types%2Flibnpmsearch' },
    publisher: { username: 'types', email: 'ts-npm-types@microsoft.com' },
    maintainers: [{ username: 'types', email: 'ts-npm-types@microsoft.com' }],
  },
]
